Life Module
===========

The life module provides tools for life insurance calculations including assurance, annuities, and reserves.

.. automodule:: actuneo.life
   :members:
   :undoc-members:
   :show-inheritance:

LifeAssurance
-------------

.. autoclass:: actuneo.life.LifeAssurance
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Annuities
---------

.. autoclass:: actuneo.life.Annuities
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Reserves
--------

.. autoclass:: actuneo.life.Reserves
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

